# Changelog

## [unreleased]

### Features

- Info mismatch just shows a warning instead of exit
- Auto build release packages
- Builds on new debian 11 machine

## [0.1.1-beta1] - 2023-07-22

### Features

- Confirm before erase
- Newest changes with support for MNVe (PCIe)

